Trait TextItem

pub trait TextItem {
    // Required method
    fn chars(&self) -> &[TextChar];

    // Provided methods
    fn bounding_rect(&self) -> Rect { ... }
    fn rotated_rect(&self) -> RotatedRect { ... }
}
A non-empty sequence of recognized characters (TextChar) that constitute a logical unit of a document such as a word or line.

Required Methods

fn chars(&self) -> &[TextChar]

Return the sequence of characters that make up this item.

Provided Methods

fn bounding_rect(&self) -> Rect

Return the bounding rectangle of all characters in this item.

fn rotated_rect(&self) -> RotatedRect

Return the oriented bounding rectangle of all characters in this item.

Implementors