pub trait TextItem {
// Required method
fn chars(&self) -> &[TextChar];
// Provided methods
fn bounding_rect(&self) -> Rect { ... }
fn rotated_rect(&self) -> RotatedRect { ... }
}Expand description
A non-empty sequence of recognized characters (TextChar) that constitute a logical unit of a document such as a word or line.
Required Methods
Provided Methods
Sourcefn bounding_rect(&self) -> Rect
fn bounding_rect(&self) -> Rect
Return the bounding rectangle of all characters in this item.
Sourcefn rotated_rect(&self) -> RotatedRect
fn rotated_rect(&self) -> RotatedRect
Return the oriented bounding rectangle of all characters in this item.